@@ -37,7 +37,7 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_DPS310.git"
 # Common imports; remove if unused or pylint will complain
 import math
 from time import sleep
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 from adafruit_register.i2c_struct import UnaryStruct, ROUnaryStruct
 from adafruit_register.i2c_bit import RWBit, ROBit
 from adafruit_register.i2c_bits import RWBits, ROBits
@@ -344,11 +344,7 @@ class DPS310:
         ie. ``Mode.ONE_TEMPERATURE``, ``Mode.CONT_TEMP`` or ``Mode.CONT_PRESTEMP``.
         See the `Mode` documentation for details.
         """
-        if (
-            self._mode_bits == Mode.IDLE
-            or self._mode_bits == Mode.ONE_PRESSURE
-            or self._mode_bits == Mode.CONT_PRESSURE
-        ):
+        if self._mode_bits in (Mode.IDLE, Mode.ONE_PRESSURE, Mode.CONT_PRESSURE):
             raise RuntimeError(
                 "Sensor mode is set to idle or pressure measurement,\
                     can't wait for a temperature measurement"
@@ -369,11 +365,7 @@ class DPS310:
         ie.  ``Mode.ONE_PRESSURE``, ``Mode.CONT_PRESSURE`` or ``Mode.CONT_PRESTEMP``
         See the `Mode` documentation for details.
         """
-        if (
-            self._mode_bits == Mode.IDLE
-            or self._mode_bits == Mode.ONE_TEMPERATURE
-            or self._mode_bits == Mode.CONT_TEMP
-        ):
+        if self._mode_bits in (Mode.IDLE, Mode.ONE_TEMPERATURE, Mode.CONT_TEMP):
             raise RuntimeError(
                 "Sensor mode is set to idle or temperature measurement,\
                     can't wait for a pressure measurement"
